#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_robot_interfaces.rob_generic_controller import RobGenericController
from pycatia.system_interfaces.any_object import AnyObject


class GenericMotionProfile(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     GenericMotionProfile
                | 
                | Interface to manage Generic Motion Profile of Robot
                | controller.
                | 
                | Role: This interface provides methods to get/set data related to Accuracy
                | Profile.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.generic_motion_profile = com_object

    def get_acceleration_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccelerationValue(double value)
                | 
                |     Retrieves acceleration value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             This out parameter contains motion acceleration of the Profile.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.GetAccelerationValue(value)

    def get_angular_acceleration_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAngularAccelerationValue(double value)
                | 
                |     Get Angular acceleration value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             Percentage of max angular acceleration of robot. The value is used
                |             when robot TCP rotate against a axis. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.GetAngularAccelerationValue(value)

    def get_angular_speed_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAngularSpeedValue(double value)
                | 
                |     Retrieves Angular Speed value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             This out parameter contains Angular Speed of the Profile.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.GetAngularSpeedValue(value)

    def get_controller(self, o_controller: RobGenericController) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetController(RobGenericController oController)
                | 
                |     Retrieves controller owning the profile.
                | 
                |     Parameters:
                | 
                |         oController
                |             This parameter contains pointer to controller. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param RobGenericController o_controller:
        :rtype: None
        """
        return self.generic_motion_profile.GetController(o_controller.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_controller'
        # # vba_code = """
        # # Public Function get_controller(generic_motion_profile)
        # #     Dim oController (2)
        # #     generic_motion_profile.GetController oController
        # #     get_controller = oController
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_motion_basis(self, basis: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMotionBasis(MotionBasis basis)
                | 
                |     Retrieves motion basis of the Profile.
                | 
                |     Parameters:
                | 
                |         basis
                |             motion basis, one of following: MOTION_ABSOLUTE, MOTION_PERCENT,
                |             MOTION_TIME 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int basis: enum motion_basis
        :rtype: None
        """
        return self.generic_motion_profile.GetMotionBasis(basis)

    def get_name(self, o_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oName)
                | 
                |     Gets name of the Motion Profile.
                | 
                |     Parameters:
                | 
                |         oName
                |             Name of the required Motion Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str o_name:
        :rtype: None
        """
        return self.generic_motion_profile.GetName(o_name)

    def get_speed_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSpeedValue(double value)
                | 
                |     Retrieves speed value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             This out parameter contains motion speed of the Profile.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.GetSpeedValue(value)

    def set_acceleration_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAccelerationValue(double value)
                | 
                |     Set acceleration value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             meaning of the value is based on the motion basis:
                |             MOTION_ABSOLUTE : absolute acceleration value. MOTION_PERCENT : 0-1, percent of
                |             max acceleration of the device MOTION_TIME : percent of total move time used on
                |             acceleration/deceleration
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.SetAccelerationValue(value)

    def set_angular_acceleration_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAngularAccelerationValue(double value)
                | 
                |     Set Angular acceleration value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             Percentage of max angular acceleration of robot. The value is used
                |             when robot TCP rotate against a axis. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.SetAngularAccelerationValue(value)

    def set_angular_speed_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAngularSpeedValue(double value)
                | 
                |     Set Angular Speed value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             Percentage of max angular speed of robot. The value is used when
                |             robot TCP rotate against a axis. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.SetAngularSpeedValue(value)

    def set_motion_basis(self, basis: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMotionBasis(MotionBasis basis)
                | 
                |     Set motion basis of the Profile.
                | 
                |     Parameters:
                | 
                |         basis
                |             motion basis, one of following: MOTION_ABSOLUTE, MOTION_PERCENT,
                |             MOTION_TIME 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int basis: enum motion_basis
        :rtype: None
        """
        return self.generic_motion_profile.SetMotionBasis(basis)

    def set_name(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iName)
                | 
                |     Set name of the Motion Profile.
                | 
                |     Parameters:
                | 
                |         iName
                |             Name of the Motion Profile to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str i_name:
        :rtype: None
        """
        return self.generic_motion_profile.SetName(i_name)

    def set_speed_value(self, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpeedValue(double value)
                | 
                |     Set speed value of the Profile.
                | 
                |     Parameters:
                | 
                |         value
                |             meaning of the value is based on the motion basis: MOTION_ABSOLUTE : absolute
                |             speed value. MOTION_PERCENT : 0-1, percent of max speed of the device
                |             MOTION_TIME : in seconds
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float value:
        :rtype: None
        """
        return self.generic_motion_profile.SetSpeedValue(value)

    def __repr__(self):
        return f'GenericMotionProfile(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.sketch_based_shape import SketchBasedShape
from pycatia.sketcher_interfaces.sketch import Sketch


class Sweep(SketchBasedShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SketchBasedShape
                |                             Sweep
                | 
                | Represents the sweep shape.
                | It is the base object for ribs and slots.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sweep = com_object

    @property
    def anchor_dir_reverse(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AnchorDirReverse() As boolean
                | 
                |     Returns the Sweep AnchorDirReverse flag (for Sweep Move Profile
                |     only).
                |     It returns TRUE if Anchor direction is reversed , FALSE if
                |     not.
                | 
                |     Returns:
                |         oAnchorDirReverse The oAnchorDirReverse flag as a
                |         boolean
                | 
                |         Example:

        :rtype: bool
        """

        return self.sweep.AnchorDirReverse

    @anchor_dir_reverse.setter
    def anchor_dir_reverse(self, value: bool):
        """
        :param bool value:
        """

        self.sweep.AnchorDirReverse = value

    @property
    def center_curve(self) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterCurve() As Sketch (Read Only)
                | 
                |     Returns the sketch used as the sweep center curve. The sweep is built along
                |     this sketch.
                | 
                |     Example:
                |         The following example returns in centerCurve the sketch used as center
                |         curve by the firstSweep sweep object:
                | 
                |          Set centerCurve = firstSweep.CenterCurve

        :rtype: Sketch
        """

        return Sketch(self.sweep.CenterCurve)

    @property
    def center_curve_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterCurveElement() As Reference
                | 
                |     Returns or sets the center curve .
                |     To set the property, you can use the following Boundary object:
                |     TriDimFeatEdge.

        :rtype: Reference
        """

        return Reference(self.sweep.CenterCurveElement)

    @center_curve_element.setter
    def center_curve_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.sweep.CenterCurveElement = value.com_object

    @property
    def is_thin(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IsThin() As boolean
                | 
                |     Returns the Sweep thin flag.
                |     It returns TRUE if the Sweep is a thin Sweep , FALSE if
                |     not.
                | 
                |     Returns:
                |         oIsThin The thin flag as a boolean
                | 
                |         Example:
                |             The following example saves in thinFlag the thin flag of Sweep
                |             firstSweep, and then sets it so that it will be now thin
                |             :
                | 
                |              Set thinFlag = firstSweep.IsThin
                |              firstSweep.IsThin = TRUE

        :rtype: bool
        """

        return self.sweep.IsThin

    @is_thin.setter
    def is_thin(self, value: bool):
        """
        :param bool value:
        """

        self.sweep.IsThin = value

    @property
    def merge_end(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MergeEnd() As boolean
                | 
                |     Returns the Sweep merge end flag (for thin Sweep only).
                |     It returns TRUE if merge ends is required , FALSE if not.
                | 
                |     Returns:
                |         oIsMergeEnd The merge end flag as a boolean
                | 
                |         Example:
                |             The following example saves in MergeEndFlag the merge end flag of
                |             Sweep firstSweep, and then sets it so that merge end will be required
                |             :
                | 
                |              Set MergeEndFlag = firstSweep.IsMergeEnd
                |              firstSweep.IsMergeEnd = TRUE

        :rtype: bool
        """

        return self.sweep.MergeEnd

    @merge_end.setter
    def merge_end(self, value: bool):
        """
        :param bool value:
        """

        self.sweep.MergeEnd = value

    @property
    def merge_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MergeMode() As CatMergeMode
                | 
                |     Returns or sets the end mode .

        :return: enum cat_merge_mode
        :rtype: int
        """

        return self.sweep.MergeMode

    @merge_mode.setter
    def merge_mode(self, value: int):
        """
        :param int value: enum cat_merge_mode
        """

        self.sweep.MergeMode = value

    @property
    def move_profile_to_path(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MoveProfileToPath() As boolean
                | 
                |     Returns the Sweep MoveProfileToPath flag (for Sweep Move Profile
                |     only).
                |     It returns TRUE if move profile is required , FALSE if
                |     not.
                | 
                |     Returns:
                |         oIsMoveProfileToPath The MoveProfileToPath flag as a
                |         boolean
                | 
                |         Example:

        :rtype: bool
        """

        return self.sweep.MoveProfileToPath

    @move_profile_to_path.setter
    def move_profile_to_path(self, value: bool):
        """
        :param bool value:
        """

        self.sweep.MoveProfileToPath = value

    @property
    def neutral_fiber(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NeutralFiber() As boolean
                | 
                |     Returns the Sweep neutral fiber flag (for thin Sweep
                |     only).
                |     It returns TRUE if the Sweep is a neutral fiber Sweep , FALSE if
                |     not.
                | 
                |     Returns:
                |         oIsNeutralFiber The neutral fiber flag as a boolean
                | 
                |         Example:
                |             The following example saves in NeutralFiberFlag the neutral fiber
                |             flag of Sweep firstSweep, and then sets it so that it will be now neutral fiber
                |             :
                | 
                |              Set NeutralFiberFlag = firstSweep.IsNeutralFiber
                |              firstSweep.IsNeutralFiber = TRUE

        :rtype: bool
        """

        return self.sweep.NeutralFiber

    @neutral_fiber.setter
    def neutral_fiber(self, value: bool):
        """
        :param bool value:
        """

        self.sweep.NeutralFiber = value

    @property
    def normal_axis_dir_reverse(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NormalAxisDirReverse() As boolean
                | 
                |     Returns the Sweep NormalAxisDirReverse flag (for Sweep Move Profile
                |     only).
                |     It returns TRUE if Normal Axis direction is reversed , FALSE if
                |     not.
                | 
                |     Returns:
                |         oNormalAxisDirReverse The oNormalAxisDirReverse flag as a
                |         boolean
                | 
                |         Example:

        :rtype: bool
        """

        return self.sweep.NormalAxisDirReverse

    @normal_axis_dir_reverse.setter
    def normal_axis_dir_reverse(self, value: bool):
        """
        :param bool value:
        """

        self.sweep.NormalAxisDirReverse = value

    @property
    def pulling_dir_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PullingDirElement() As Reference
                | 
                |     Returns or sets the pulling direction .
                |     To set the property, you can use one of the following Boundary objects:
                |     PlanarFace, RectilinearTriDimFeatEdge, RectilinearBiDimFeatEdge,
                |     RectilinearMonoDimFeatEdge.

        :rtype: Reference
        """

        return Reference(self.sweep.PullingDirElement)

    @pulling_dir_element.setter
    def pulling_dir_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.sweep.PullingDirElement = value.com_object

    @property
    def reference_surface_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReferenceSurfaceElement() As Reference
                | 
                |     Returns or sets the reference surface .
                |     To set the property, you can use the following Boundary object: Face.

        :rtype: Reference
        """

        return Reference(self.sweep.ReferenceSurfaceElement)

    @reference_surface_element.setter
    def reference_surface_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.sweep.ReferenceSurfaceElement = value.com_object

    def set_keep_angle_option(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetKeepAngleOption()
                | 
                |     Actives KeepAngleOption.

        :rtype: None
        """
        return self.sweep.SetKeepAngleOption()

    def __repr__(self):
        return f'Sweep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeBlend(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeBlend
                | 
                | Represents the hybrid shape blended surface object.
                | Role: To access the data of the hybrid shape blended surface
                | object.
                | 
                | This data includes:
                | 
                |     Two support surfaces, one at each limit of the blended
                |     surface
                |     Two curves, one for each support surface
                |     The curve closing points
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeBlend
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_blend = com_object

    @property
    def coupling(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Coupling() As long
                | 
                |     Returns or sets the type of coupling between the limits of the
                |     blend.
                |     Legal values: The values representing the type of coupling can
                |     be:
                | 
                |     1
                |         Ratio: the curves are coupled according to the curvilinear abscissa
                |         ratio 
                |     2
                |         Tangency: the curves are coupled according to their tangency
                |         discontinuity points. If they do not have the same number of tangency
                |         discontinuity points, they cannot be coupled and an error message is displayed
                |         
                |     3
                |         Tangency then curvature: the curves are coupled according to their
                |         tangency discontinuity points first, then according to their curvature
                |         discontinuity points. If they do not have the same number of tangency and
                |         curvature discontinuity points, they cannot be coupled and an error message is
                |         displayed 
                |     4
                |         Vertices: the curves are coupled according to their vertices. If they
                |         do not have the same number of vertices, they cannot be coupled and an error
                |         message is displayed 
                |     5
                |         Spine: coupling is completely driven by a curve (called spine)
                |         
                | 
                |     Example:
                |         This example retrieves in CouplingVal the coupling value of the
                |         ShpBlend hybrid shape blended feature.
                | 
                |          CouplingVal = ShpBlend.Coupling

        :rtype: int
        """

        return self.hybrid_shape_blend.Coupling

    @coupling.setter
    def coupling(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_blend.Coupling = value

    @property
    def ruled_developable_surface(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RuledDevelopableSurface() As boolean
                | 
                |     Returns or sets the ruled developable surface mode.
                |     TRUE means that the mode is enabled and FALSE means that it is disabled.

        :rtype: bool
        """

        return self.hybrid_shape_blend.RuledDevelopableSurface

    @ruled_developable_surface.setter
    def ruled_developable_surface(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_blend.RuledDevelopableSurface = value

    @property
    def smooth_angle_threshold(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothAngleThreshold() As Angle (Read Only)
                | 
                |     Returns the angular threshold.

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_blend.SmoothAngleThreshold)

    @property
    def smooth_angle_threshold_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothAngleThresholdActivity() As boolean
                | 
                |     Returns or sets information whether a blending operation is smoothed or
                |     not.
                |     TRUE if the blending operation is smoothed, or FALSE otherwise (FALSE if
                |     not specified).

        :rtype: bool
        """

        return self.hybrid_shape_blend.SmoothAngleThresholdActivity

    @smooth_angle_threshold_activity.setter
    def smooth_angle_threshold_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_blend.SmoothAngleThresholdActivity = value

    @property
    def smooth_deviation(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothDeviation() As Length (Read Only)
                | 
                |     Returns the deviation value (length) from guide curves allowed during a
                |     sweeping operation in order to smooth it.

        :rtype: Length
        """

        return Length(self.hybrid_shape_blend.SmoothDeviation)

    @property
    def smooth_deviation_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothDeviationActivity() As boolean
                | 
                |     Returns or sets information whether a deviation from guide curves is
                |     allowed or not.
                |     Gives the information on performing smoothing during blending
                |     operation.
                |     TRUE if a deviation from guide curves is allowed, or FALSE otherwise (FALSE
                |     if not specified).

        :rtype: bool
        """

        return self.hybrid_shape_blend.SmoothDeviationActivity

    @smooth_deviation_activity.setter
    def smooth_deviation_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_blend.SmoothDeviationActivity = value

    @property
    def spine(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Spine() As Reference
                | 
                |     Returns or sets a curve used as spine for coupling in Blend computation.
                |     Setting the spine curve also changes coupling mode to CATGSMSpineCoupling. In
                |     order to remove the spine, set another coupling mode.
                | 
                |     Parameters:
                | 
                |         iSpine
                |             spine curve

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_blend.Spine)

    @spine.setter
    def spine(self, reference_spine: Reference):
        """
        :param Reference reference_spine:
        """

        self.hybrid_shape_blend.Spine = reference_spine.com_object

    def get_border_mode(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBorderMode(long iBlendLimit) As long
                | 
                |     Returns the type of border to a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose type of border is to be
                |             retrieved.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The type of border
                |         Legal values:
                | 
                |         1
                |             The border of the blend will be tangent to the border of the
                |             support surface, or if the curve ends on the border of a face of the support
                |             surface, then the border of the blend will be tangent to the border face.
                |             
                |         2
                |             The border of the blend is not constrained. 
                | 
                | Example:
                |     This example retrieves in BorderType the type of border of the first limit
                |     of the ShpBlend hybrid shape blended feature.
                | 
                |      BorderType = ShpBlend.GetBorderMode(1)

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetBorderMode(i_blend_limit)

    def get_closing_point(self, i_blend_limit: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetClosingPoint(long iBlendLimit) As Reference
                | 
                |     Returns the closing point of a closed curve of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose curve closing point is
                |             returned.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The retrieved closing point 
                | 
                | Example:
                |     This example retrieves in ClosingPoint the closing point of the curve of
                |     the second limit of the ShpBlend hybrid shape blended
                |     feature.
                | 
                |      Dim ClosingPoint As Reference
                |      ClosingPoint = ShpBlend.GetClosingPoint(2)

        :param int i_blend_limit:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_blend.GetClosingPoint(i_blend_limit))

    def get_continuity(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetContinuity(long iBlendLimit) As long
                | 
                |     Retrieves the continuity of a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose continuity is to be
                |             retrieved.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The retrieved continuity.
                |         Legal values:
                | 
                |         0
                |             Point continuity 
                |         1
                |             Tangency continuity 
                |         2
                |             Curvature continuity 
                | 
                | Example:
                |     This example retrieves in Continuity the continuity of the second limit of
                |     the ShpBlend hybrid shape blended feature.
                | 
                |      Continuity = ShpBlend.GetContinuity(2)

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetContinuity(i_blend_limit)

    def get_curve(self, i_blend_limit: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCurve(long iBlendLimit) As Reference
                | 
                |     Returns a curve from the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend from which the curve will be
                |             retrieved.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The retrieved curve 
                | 
                | Example:
                |     This example retrieves in BlendCurve the curve of the second limit of the
                |     ShpBlend hybrid shape blended feature.
                | 
                |      Dim BlendCurve As Reference
                |      BlendCurve = ShpBlend.GetCurve(2)

        :param int i_blend_limit:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_blend.GetCurve(i_blend_limit))

    def get_orientation(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetOrientation(long iBlendLimit) As long
                | 
                |     Returns the orientation of a curve of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose curve orientation is to be
                |             retrieved.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The orientation to set to the curve.
                |         Legal values: 1 for direct and -1 for reverse 
                | 
                | Example:
                |     This example retrieves in Orientation the orientation of the second limit
                |     of the ShpBlend hybrid shape blended feature.
                | 
                |      Orientation = ShpBlend.GetOrientation(2)

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetOrientation(i_blend_limit)

    def get_ruled_developable_surface_connection(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRuledDevelopableSurfaceConnection(long iBlendLimit) As
                | long
                | 
                |     Returns or sets the ruled developable surface connection
                |     type.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend for which the connection type is to be
                |             set.
                |             Legal values: 1 for the start limit, and 2 for the end one
                |             
                |         oBlendConnection
                |             The value of connection type
                |             Legal values:
                | 
                |             1
                |                 Connect to both extremities 
                |             2
                |                 Free first curve 
                |             3
                |                 Free second curve

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetRuledDevelopableSurfaceConnection(i_blend_limit)

    def get_support(self, i_blend_limit: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSupport(long iBlendLimit) As Reference
                | 
                |     Returns a support from the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose support is to be
                |             retrieved.
                |             Legal values: 1 for the first support, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The retrieved support surface 
                | 
                | Example:
                |     This example retrieves in SupportSurf the support surface of the second
                |     limit of the ShpBlend hybrid shape blended feature.
                | 
                |      Dim SupportSurf As Reference 
                |      SupportSurf = ShpBlend.GetSupport(2)

        :param int i_blend_limit:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_blend.GetSupport(i_blend_limit))

    def get_tension_in_double(self, i_blend_limit: int, i_rank: int) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTensionInDouble(long iBlendLimit,
                | long iRank) As RealParam
                | 
                |     Returns the tension values of a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend from which the tension type and values are
                |             to be retrieved.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                |         iRank
                |             The rank of the value to retrieve among those available, depending
                |             on the tension type.
                |             Legal values: iRank can take the following values:
                | 
                |             1
                |                 With default tension and constant tension, for the unique
                |                 available value, and with linear tension for the first value
                |                 
                |             2
                |                 With linear tension for the second value 
                | 
                |     Returns:
                |         The retrieved tension value 
                | 
                | Example:
                |     This example retrieves in TensionVal the tension value of the tension,
                |     supposed to be a constant tension, of the first limit of the ShpBlend hybrid
                |     shape blended feature.
                | 
                |      Dim ConstTensionVal As RealParam
                |      Set ConstTensionVal = ShpBlend.GetTensionInDouble(1, 1)

        :param int i_blend_limit:
        :param int i_rank:
        :rtype: RealParam
        """
        return RealParam(self.hybrid_shape_blend.GetTensionInDouble(i_blend_limit, i_rank))

    def get_tension_type(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTensionType(long iBlendLimit) As long
                | 
                |     Returns the tension type of a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend from which the tension type is to be
                |             retrieved.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The value of tension type
                |         Legal values:
                | 
                |         1
                |             Default tension 
                |         2
                |             Constant tension 
                |         3
                |             Linear tension 
                | 
                | Example:
                |     This example retrieves in TensionType the tension type of the first limit
                |     of the ShpBlend hybrid shape blended feature.
                | 
                |      TensionType.GetTensionType(1)

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetTensionType(i_blend_limit)

    def get_transition(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTransition(long iBlendLimit) As long
                | 
                |     Returns the transition orientation from a limit of the
                |     blend.
                |     Let T be the tangent to the wire, and N be the normal to the skin body. The
                |     transition orientation defines how the blend goes from the initial wires: it
                |     takes the direction of iTransition*(T^N), where ^ is the cross
                |     product.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose transition orientation is to be
                |             retrieved.
                |             Legal values: 1 for the first support, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The retrieved value of transition orientation.
                |         Legal values: 1 for direct and -1 for reverse 
                | 
                | Example:
                |     This example retrieves in TransOrientation the transition orientation of
                |     the second limit of the ShpBlend hybrid shape blended
                |     feature.
                | 
                |      TransOrientation = ShpBlend.GetTransition(2)

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetTransition(i_blend_limit)

    def get_trim_support(self, i_blend_limit: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTrimSupport(long iBlendLimit) As long
                | 
                |     Returns whether a support of the blend will be trimmed
                |     off.
                |     If the support is set to be trimmed, it will be trimmed using the curve
                |     then joined to the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose support is to be
                |             trimmed.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                | 
                |     Returns:
                |         The trim support mode
                |         Legal values:
                | 
                |         1
                |             No trim 
                |         2
                |             The support will be trimmed 
                | 
                | Example:
                |     This example retrieves whether the second limit of the ShpBlend hybrid
                |     shape blended feature should be trimmed off.
                | 
                |      IsTrimmed = ShpBlend.GetTrimSupport(2)

        :param int i_blend_limit:
        :rtype: int
        """
        return self.hybrid_shape_blend.GetTrimSupport(i_blend_limit)

    def insert_coupling(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertCoupling(long iPosition)
                | 
                |     Inserts a coupling into the blend.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position of the coupling in the list of couplings. Setting
                |             iPosition to 0 inserts the coupling at the end of the list.
                |             
                | 
                |     Example:
                |         This example inserts a coupling at the end of the coupling list of the
                |         ShpBlend hybrid shape blended feature.
                | 
                |          ShpBlend.InsertCouplingt 0

        :param int i_position:
        :rtype: None
        """
        return self.hybrid_shape_blend.InsertCoupling(i_position)

    def insert_coupling_point(self, i_coupling_index: int, i_position: int, i_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertCouplingPoint(long iCouplingIndex,
                | long iPosition,
                | Reference iPoint)
                | 
                |     Inserts a coupling point to a coupling of the blend.
                | 
                |     Parameters:
                | 
                |         iCouplingIndex
                |             The index of the coupling in the list of couplings into which the
                |             coupling point will be inserted. 
                |         iPosition
                |             The position of the coupling point in the list of coupling points.
                |             Setting iPosition to 0 inserts the coupling point at the end of the list.
                |             
                |         iPoint
                |             The coupling point to be inserted. This point must lay on the
                |             section with the same position.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Vertex. 
                | 
                | Example:
                |     This example inserts the Point23 point into the third coupling at the end
                |     of the list of coupling points of the ShpBlend hybrid shape blended
                |     feature.
                | 
                |      ShpBlend.InsertCouplingPoint 3, 0, Point23

        :param int i_coupling_index:
        :param int i_position:
        :param Reference i_point:
        :rtype: None
        """
        return self.hybrid_shape_blend.InsertCouplingPoint(i_coupling_index, i_position, i_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_coupling_point'
        # # vba_code = """
        # # Public Function insert_coupling_point(hybrid_shape_blend)
        # #     Dim iCouplingIndex (2)
        # #     hybrid_shape_blend.InsertCouplingPoint iCouplingIndex
        # #     insert_coupling_point = iCouplingIndex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_border_mode(self, i_blend_limit: int, i_border: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetBorderMode(long iBlendLimit,
                | long iBorder)
                | 
                |     Sets the type of border to a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose type of border is to be
                |             set.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                |         iBorder
                |             The type of border
                |             Legal values:
                | 
                |             1
                |                 The border of the blend will be tangent to the border of the
                |                 support surface, or if the curve ends on the border of a face of the support
                |                 surface, then the border of the blend will be tangent to the border face.
                |                 
                |             2
                |                 The border of the blend is not constrained. 
                |             3
                |                 The border of the blend will be tangent to the border of the
                |                 support surface at the start extremity of the curve, or if the curve ends on
                |                 the border of a face of the support surface, then the border of the blend will
                |                 be tangent to the border face at the start extremity of the curve.
                |                 
                |             4
                |                 The border of the blend will be tangent to the border of the
                |                 support surface at the end extremity of the curve, or if the curve ends on the
                |                 border of a face of the support surface, then the border of the blend will be
                |                 tangent to the border face at the end extremity of the curve.
                |                 
                | 
                |     Example:
                |         This example sets the type of border of the second limit of the
                |         ShpBlend hybrid shape blended feature to "no
                |         constraint".
                | 
                |          ShpBlend.SetBorderMode 2, 2

        :param int i_blend_limit:
        :param int i_border:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetBorderMode(i_blend_limit, i_border)

    def set_closing_point(self, i_blend_limit: int, i_closing_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetClosingPoint(long iBlendLimit,
                | Reference iClosingPoint)
                | 
                |     Sets a new closing point to a closed curve of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose curve will be set a new closing
                |             point.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                |         iClosingPoint
                |             The closing point to be set. This point must lay on the curve of
                |             the blend limit.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Vertex. 
                | 
                | Example:
                |     This example sets the Point10 point as the closing point to the second
                |     limit of the ShpBlend hybrid shape blended feature.
                | 
                |      ShpBlend.SetClosingPoint 2, Point10

        :param int i_blend_limit:
        :param Reference i_closing_point:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetClosingPoint(i_blend_limit, i_closing_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_closing_point'
        # # vba_code = """
        # # Public Function set_closing_point(hybrid_shape_blend)
        # #     Dim iBlendLimit (2)
        # #     hybrid_shape_blend.SetClosingPoint iBlendLimit
        # #     set_closing_point = iBlendLimit
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_continuity(self, i_blend_limit: int, i_continuity: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetContinuity(long iBlendLimit,
                | long iContinuity)
                | 
                |     Sets the continuity to a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose continuity is to be
                |             set.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                |         iContinuity
                |             The continuity to set
                |             Legal values:
                | 
                |             0
                |                 Point continuity 
                |             1
                |                 Tangency continuity 
                |             2
                |                 Curvature continuity 
                | 
                |     Example:
                |         This example sets the continuity of the second limit of the ShpBlend
                |         hybrid shape blended feature to tangency continuity.
                | 
                |          ShpBlend.SetContinuity 2, 1

        :param int i_blend_limit:
        :param int i_continuity:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetContinuity(i_blend_limit, i_continuity)

    def set_curve(self, i_blend_limit: int, i_curve: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCurve(long iBlendLimit,
                | Reference iCurve)
                | 
                |     Sets a curve to the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend to which the curve will be
                |             set.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                |         iCurve
                |             The curve to be set.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): TriDimFeatEdge and BiDimFeatEdge. 
                | 
                | Example:
                |     This example sets the CurveForBlend curve to the second limit of the
                |     ShpBlend hybrid shape blended feature.
                | 
                |      ShpBlend.SetCurve 2, CurveForBlend

        :param int i_blend_limit:
        :param Reference i_curve:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetCurve(i_blend_limit, i_curve.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_curve'
        # # vba_code = """
        # # Public Function set_curve(hybrid_shape_blend)
        # #     Dim iBlendLimit (2)
        # #     hybrid_shape_blend.SetCurve iBlendLimit
        # #     set_curve = iBlendLimit
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_orientation(self, i_blend_limit: int, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetOrientation(long iBlendLimit,
                | long iOrientation)
                | 
                |     Sets the orientation of a curve of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose curve orientation is to be
                |             set.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                |         iOrientation
                |             The orientation to set to the curve.
                |             Legal values: 1 for direct and -1 for reverse 
                | 
                |     Example:
                |         This example sets the orientation of the second limit of the ShpBlend
                |         hybrid shape blended feature to direct.
                | 
                |          ShpBlend.SetOrientation 2, 1

        :param int i_blend_limit:
        :param int i_orientation:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetOrientation(i_blend_limit, i_orientation)

    def set_ruled_developable_surface_connection(self, i_blend_limit: int, i_blend_connection: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRuledDevelopableSurfaceConnection(long iBlendLimit,
                | long iBlendConnection)

        :param int i_blend_limit:
        :param int i_blend_connection:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetRuledDevelopableSurfaceConnection(i_blend_limit, i_blend_connection)

    def set_smooth_angle_threshold(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSmoothAngleThreshold(double iAngle)
                | 
                |     Sets the angular threshold.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             The angular threshold

        :param float i_angle:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetSmoothAngleThreshold(i_angle)

    def set_smooth_deviation(self, i_length: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSmoothDeviation(double iLength)
                | 
                |     Sets the deviation value (length) from guide curves allowed during sweeping
                |     operation in order to smooth it.
                | 
                |     Parameters:
                | 
                |         iLength
                |             The deviation value

        :param float i_length:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetSmoothDeviation(i_length)

    def set_support(self, i_blend_limit: int, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSupport(long iBlendLimit,
                | Reference iSupport)
                | 
                |     Sets a support to the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose support is to be set.
                |             Legal values: 1 for the first support, and 2 for the second one
                |             
                |         iSupport
                |             The support surface to be set. The curve of the blend limit must
                |             lay on the surface.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Face. 
                | 
                | Example:
                |     This example sets the SupportSurf surface as the support of the second
                |     limit of the ShpBlend hybrid shape blended feature.
                | 
                |      ShpBlend.SetSupport 2, SupportSurf

        :param int i_blend_limit:
        :param Reference i_support:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetSupport(i_blend_limit, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_support'
        # # vba_code = """
        # # Public Function set_support(hybrid_shape_blend)
        # #     Dim iBlendLimit (2)
        # #     hybrid_shape_blend.SetSupport iBlendLimit
        # #     set_support = iBlendLimit
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tension_in_double(self, i_blend_limit: int, i_tension_type: int, i_first_tension: float,
                              i_second_tension: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTensionInDouble(long iBlendLimit,
                | long iTensionType,
                | double iFirstTension,
                | double iSecondTension)
                | 
                |     Sets the tension values to a limit of the blend. The values must be
                |     expressed as doubles and must be positive.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend to which the tension values are to be
                |             set.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                |         iTensionType
                |             The tension type
                |             Legal values:
                | 
                |             1
                |                 Default tension 
                |             2
                |                 Constant tension 
                |             3
                |                 Linear tension 
                | 
                |         iFirstTension
                |             The value for the first tension. It must be used with any tension
                |             type
                |             Legal values: it must be a double and positive. 
                |         iSecondTension
                |             The value for the second tension. It can be used with linear
                |             tension only
                |             Legal values: it must be a double and positive. 
                | 
                |     Example:
                |         This example sets the tension values of the tension, supposed to be a
                |         linear tension, of the first limit of the ShpBlend hybrid shape blended feature
                |         to respectively 1.5 and 0.5.
                | 
                |          ShpBlend.SetTensionInDouble 1, 3, 1.5, 0.5

        :param int i_blend_limit:
        :param int i_tension_type:
        :param float i_first_tension:
        :param float i_second_tension:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetTensionInDouble(i_blend_limit, i_tension_type, i_first_tension,
                                                          i_second_tension)

    def set_tension_type(self, i_blend_limit: int, i_tension_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTensionType(long iBlendLimit,
                | long iTensionType)
                | 
                |     Sets the tension type of a limit of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend for which the tension type is to be
                |             set.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                |         iBlendLimit
                |             The value of tension type
                |             Legal values:
                | 
                |             1
                |                 Default tension 
                |             2
                |                 Constant tension 
                |             3
                |                 Linear tension 
                |             4
                |                 SType tension 
                | 
                |     Example:
                |         This example sets the tension type as Default Tension for the first
                |         limit of the ShpBlend hybrid shape blended feature.
                | 
                |          ShpBlend.SetTensionType 1, 1

        :param int i_blend_limit:
        :param int i_tension_type:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetTensionType(i_blend_limit, i_tension_type)

    def set_transition(self, i_blend_limit: int, i_transition: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTransition(long iBlendLimit,
                | long iTransition)
                | 
                |     Sets the transition orientation to a limit of the blend.
                |     Role: Let T be the tangent to the wire, and N be the normal to the skin
                |     body. The transition orientation defines how the blend goes from the initial
                |     wires: it takes the direction of iTransition*(T^N), where ^ is the cross
                |     product.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose transition orientation is to be
                |             set.
                |             Legal values: 1 for the first support, and 2 for the second one
                |             
                |         iTransition
                |             The value of transition orientation.
                |             Legal values: 1 for direct and -1 for reverse 
                | 
                |     Example:
                |         This example sets the transition orientation of the second limit of the
                |         ShpBlend hybrid shape blended feature to reverse.
                | 
                |          ShpBlend.SetTransition 2, -1

        :param int i_blend_limit:
        :param int i_transition:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetTransition(i_blend_limit, i_transition)

    def set_trim_support(self, i_blend_limit: int, i_trim_support: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTrimSupport(long iBlendLimit,
                | long iTrimSupport)
                | 
                |     Sets whether a support of the blend is to be trimmed off.
                |     If the support is set to be trimmed, it will be trimmed using the curve
                |     then joined to the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose support is to be
                |             trimmed.
                |             Legal values: 1 for the first limit, and 2 for the second one
                |             
                |         iTrimSupport
                |             The trim support mode
                |             Legal values:
                | 
                |             1
                |                 No trim 
                |             2
                |                 The support will be trimmed 
                | 
                |     Example:
                |         This example sets that the second limit of the ShpBlend hybrid shape
                |         blended feature should be trimmed off.
                | 
                |          ShpBlend.SetTrimSupport 2, 2

        :param int i_blend_limit:
        :param int i_trim_support:
        :rtype: None
        """
        return self.hybrid_shape_blend.SetTrimSupport(i_blend_limit, i_trim_support)

    def unset_closing_point(self, i_blend_limit: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub UnsetClosingPoint(long iBlendLimit)
                | 
                |     Unsets the closing point of a closed curve of the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose curve closing point is
                |             unset.
                |             Legal values: 1 for the first curve, and 2 for the second one
                |             
                | 
                |     Example:
                |         This example unsets the closing point of the second limit of the
                |         ShpBlend hybrid shape blended feature.
                | 
                |          ShpBlend.UnsetClosingPoint 2

        :param int i_blend_limit:
        :rtype: None
        """
        return self.hybrid_shape_blend.UnsetClosingPoint(i_blend_limit)

    def unset_support(self, i_blend_limit: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub UnsetSupport(long iBlendLimit)
                | 
                |     Unsets a support from the blend.
                | 
                |     Parameters:
                | 
                |         iBlendLimit
                |             The limit of the blend whose support is to be
                |             unset.
                |             Legal values: 1 for the first support, and 2 for the second one
                |             
                | 
                |     Example:
                |         This example unsets the support surface of the second limit of the
                |         ShpBlend hybrid shape blended feature.
                | 
                |          ShpBlend.UnsetSupport 2

        :param int i_blend_limit:
        :rtype: None
        """
        return self.hybrid_shape_blend.UnsetSupport(i_blend_limit)

    def __repr__(self):
        return f'HybridShapeBlend(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_set import AnalysisSet
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisSets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisSets
                | 
                | The collection of analysis sets.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisSet)
        self.analysis_sets = com_object

    def add(self, i_type: str, i_set_type: int) -> AnalysisSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iType,
                | CATAnalysisSetType iSetType) As AnalysisSet
                | 
                |     Creates a new analysis set and adds it to the analysis sets
                |     collection.
                |     The analysis set will be aggregated on the Analysis Model
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of the set to create. 
                |         iSetType
                |             The category of the set for update. 
                | 
                |     Returns:
                |         The created Analysis Set 
                |     Example:
                | 
                |           This example create ThisAnalysisSet in the analysisSetsanalysis
                |
                |          sets collection. The set to create is supposed to be a load set
                |          defined as an input of 
                | 
                |          the case for the update.
                |
                |          Dim ThisAnalysisSet As AnalysisSet
                |          Set ThisAnalysisSet = analysisSets.Add("LoadSet", 0)

        :param str i_type:
        :param int i_set_type: enum cat_analysis_set_type
        :rtype: AnalysisSet
        """
        return AnalysisSet(self.analysis_sets.Add(i_type, i_set_type))

    def add_existing_set(self, i_set: AnalysisSet, i_set_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddExistingSet(AnalysisSet iSet,
                | CATAnalysisSetType iSetType)
                | 
                |     Adds an existing analysis set to the analysis sets
                |     collection.
                | 
                |     Parameters:
                | 
                |         iSet
                |             The Existing Analysis Set. 
                |         iSetType
                |             The category of the set for update. 
                | 
                |     Example:
                | 
                |           This example adds ThisAnalysisSet in the analysisSetsanalysis
                |
                |          sets collection. The set to add is supposed to be a restrain set
                |          defined as an input of the case for the update.
                |
                |          Dim ThisAnalysisSet As AnalysisSet
                |          ...
                |          analysisSets.AddExistingSet(ThisAnalysisSet, 0)

        :param AnalysisSet i_set:
        :param int i_set_type: enum cat_analysis_set_type
        :rtype: None
        """
        return self.analysis_sets.AddExistingSet(i_set.com_object, i_set_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_existing_set'
        # # vba_code = """
        # # Public Function add_existing_set(analysis_sets)
        # #     Dim iSet (2)
        # #     analysis_sets.AddExistingSet iSet
        # #     add_existing_set = iSet
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item(self, i_index: cat_variant, i_search_type: int) -> AnalysisSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex,
                | CATAnalysisSetSearchType iSerachType) As AnalysisSet
                | 
                |     Returns an analysis set using its index or its name from the analysis sets
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis set to retrieve from the
                |             collection of analysis sets. As a numerics, this index is the rank of the
                |             analysis set in the collection. The index of the first analysis set in the
                |             collection is 1, and the index of the last analysis set is Count. As a string,
                |             it is the name you assigned to the analysis set using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     iSerachType
                |         The criterion of searching the set.
                |         CATAnalysisSetType.CATAnalysisSetSearchType
                |     Returns:
                |         The retrieved analysis set 
                |     Example:
                | 
                |           This example retrieves in ThisAnalysisSet the third analysis
                |           set,
                |          and in ThatAnalysisSet the analysis set named
                |          MySet in the analysis set collection of an Analysis Case of analysis
                |          model.
                |
                |          Dim ThisAnalysisSet As AnalysisSet
                |          Set ThisAnalysisSet = analysisCase.AnalysisSets.Item(3,1)
                |          Dim ThatAnalysisSet As AnalysisSet
                |          Set ThatAnalysisSet = analysisCase.AnalysisSets.Item("MySet")

        :param cat_variant i_index:
        :param int i_search_type: enum cat_analysis_set_search_type
        :rtype: AnalysisSet
        """
        return AnalysisSet(self.analysis_sets.Item(i_index, i_search_type))

    def item_by_type(self, i_type: str) -> AnalysisSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ItemByType(CATBSTR iType) As AnalysisSet
                | 
                |     Returns an analysis set using its type from the analysis sets
                |     collection.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of the set required for the search 
                | 
                |     Returns:
                |         The retrieved analysis set 
                |     Example:
                | 
                |          This example retrieves in ThisAnalysisSet the "LoadSet" analysis set
                |          in the analysis set collection.
                |
                |          Dim ThisAnalysisSet As AnalysisSet
                |          Set ThisAnalysisSet = analysisCase.AnalysisSets.ItemByType("LoadSet")

        :param str i_type:
        :rtype: AnalysisSet
        """
        return AnalysisSet(self.analysis_sets.ItemByType(i_type))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a set using its index or its name from the set
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the set to retrieve from the collection of
                |             sets. As a numeric, this index is the rank of the set in the collection. The
                |             index of the first set in the collection is 1, and the index of the last set is
                |             Count. As a string, it is the name you assigned to the set using the
                |             
                | 
                |         AnyObject.Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.analysis_sets.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(analysis_sets)
        # #     Dim iIndex (2)
        # #     analysis_sets.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisSets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_interaction import ABQInteraction
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.axis_system import AxisSystem
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQSmoothCoupling(ABQInteraction):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQInteraction
                |                         ABQSmoothCoupling
                | 
                | Represents an Abaqus smooth coupling (ABQSmoothCoupling)
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_smooth_coupling = com_object

    @property
    def num_exclusion_regions(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumExclusionRegions() As long (Read Only)
                | 
                |     Retrieves the number of currently active exclusion regions.

        :rtype: int
        """

        return self.abq_smooth_coupling.NumExclusionRegions

    @property
    def num_supports(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumSupports() As long (Read Only)
                | 
                |     Retrieves the number of supports.

        :rtype: int
        """

        return self.abq_smooth_coupling.NumSupports

    @property
    def ur1(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UR1() As boolean
                | 
                |     Returns or sets the UR1 degree of freedom.

        :rtype: bool
        """

        return self.abq_smooth_coupling.UR1

    @ur1.setter
    def ur1(self, value: bool):
        """
        :param bool value:
        """

        self.abq_smooth_coupling.UR1 = value

    @property
    def ur2(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UR2() As boolean
                | 
                |     Returns or sets the UR2 degree of freedom.

        :rtype: bool
        """

        return self.abq_smooth_coupling.UR2

    @ur2.setter
    def ur2(self, value: bool):
        """
        :param bool value:
        """

        self.abq_smooth_coupling.UR2 = value

    @property
    def ur3(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UR3() As boolean
                | 
                |     Returns or sets the UR3 degree of freedom.

        :rtype: bool
        """

        return self.abq_smooth_coupling.UR3

    @ur3.setter
    def ur3(self, value: bool):
        """
        :param bool value:
        """

        self.abq_smooth_coupling.UR3 = value

    @property
    def local_csys(self) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property localCsys() As AxisSystem
                | 
                |     Returns or sets the local coordinate system. If nothing is passed in then
                |     it defaults to the global coordinate system.

        :rtype: AxisSystem
        """

        return AxisSystem(self.abq_smooth_coupling.localCsys)

    @local_csys.setter
    def local_csys(self, value: AxisSystem):
        """
        :param AxisSystem value:
        """

        self.abq_smooth_coupling.localCsys = value

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Adds a support to the coupling. If the support already exists, it is
                |     removed from the coupling. If an attempt to remove the last support is made,
                |     the support is maintained and an error is returned.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the smooth
                |             coupling is applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the smooth
                |             coupling is applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_smooth_coupling.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_smooth_coupling)
        # #     Dim iProduct (2)
        # #     abq_smooth_coupling.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     AddSupportFromReference - adds a support to the coupling. If the support
                |     already exists, it is removed from the coupling. If an attempt to remove the
                |     last support is made, the support is maintained and an error is
                |     returned.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The reference to the product as a CATIAReference. 
                |         iSupport
                |             The reference to the support as a CATIAReference.

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_smooth_coupling.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_smooth_coupling)
        # #     Dim iReference (2)
        # #     abq_smooth_coupling.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def clear_exclusion_regions(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearExclusionRegions()
                | 
                |     Clears the exclusion regions list.

        :rtype: None
        """
        return self.abq_smooth_coupling.ClearExclusionRegions()

    def clear_handler(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ClearHandler()
                | 
                |     Clears the handler.

        :rtype: None
        """
        return self.abq_smooth_coupling.ClearHandler()

    def get_exclusion_regions(self, o_products: tuple, o_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetExclusionRegions(CATSafeArrayVariant oProducts,
                | CATSafeArrayVariant oRegions)
                | 
                |     Returns the exclusion regions for the coupling. param oProducts Returned
                |     safe array of products for the excluded region, as CATIAReferences. This array
                |     has a one-to-one mapping with the regions array.
                | 
                |     Parameters:
                | 
                |         oRegions
                |             Returned safe array of regions to exclude, as CATIAReferences. This
                |             array has a one-to-one mapping with the products
                |             array.

        :param tuple o_products:
        :param tuple o_regions:
        :rtype: None
        """
        return self.abq_smooth_coupling.GetExclusionRegions(o_products, o_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_exclusion_regions'
        # # vba_code = """
        # # Public Function get_exclusion_regions(abq_smooth_coupling)
        # #     Dim oProducts (2)
        # #     abq_smooth_coupling.GetExclusionRegions oProducts
        # #     get_exclusion_regions = oProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_handler(self, o_product: Reference, o_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetHandler(Reference oProduct,
                | Reference oRef)
                | 
                |     Returns the handler for the coupling.
                | 
                |     Parameters:
                | 
                |         oProduct
                |             The product for the handler. 
                |         oRef
                |             The reference to the handler.

        :param Reference o_product:
        :param Reference o_ref:
        :rtype: None
        """
        return self.abq_smooth_coupling.GetHandler(o_product.com_object, o_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_handler'
        # # vba_code = """
        # # Public Function get_handler(abq_smooth_coupling)
        # #     Dim oProduct (2)
        # #     abq_smooth_coupling.GetHandler oProduct
        # #     get_handler = oProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_local_csys_from_publication(self, o_product: Product, o_pub_axis_system: AxisSystem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLocalCsysFromPublication(Product oProduct,
                | AxisSystem oPubAxisSystem)
                | 
                |     Gets the published local coordinate system of for the
                |     coupling.
                | 
                |     Parameters:
                | 
                |         oProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         oPubAxisSystem
                |             The CATIA Axis system.
                | 
                |             Refer: CATIAAxisSystem

        :param Product o_product:
        :param AxisSystem o_pub_axis_system:
        :rtype: None
        """
        return self.abq_smooth_coupling.GetLocalCsysFromPublication(o_product.com_object, o_pub_axis_system.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_local_csys_from_publication'
        # # vba_code = """
        # # Public Function get_local_csys_from_publication(abq_smooth_coupling)
        # #     Dim oProduct (2)
        # #     abq_smooth_coupling.GetLocalCsysFromPublication oProduct
        # #     get_local_csys_from_publication = oProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_supports(self, o_products: tuple, o_supports: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSupports(CATSafeArrayVariant oProducts,
                | CATSafeArrayVariant oSupports)
                | 
                |     Returns the supports for the coupling.
                | 
                |     Parameters:
                | 
                |         oProducts
                |             Returned safe array of products for the supports, as
                |             CATIAReferences. This array has a one-to-one mapping with the supports array.
                |             
                |         oSupports
                |             Returned safe array of supports, as CATIAReferences. This array has
                |             a one-to-one mapping with the products array.

        :param tuple o_products:
        :param tuple o_supports:
        :rtype: None
        """
        return self.abq_smooth_coupling.GetSupports(o_products, o_supports)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_supports'
        # # vba_code = """
        # # Public Function get_supports(abq_smooth_coupling)
        # #     Dim oProducts (2)
        # #     abq_smooth_coupling.GetSupports oProducts
        # #     get_supports = oProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_exclusion_regions(self, i_products: tuple, i_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExclusionRegions(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iRegions)
                | 
                |     Sets the exclusion regions for the coupling. Any previously set exclusion
                |     regions will be replaced with this new list. The list of excluded regions can
                |     be cleared by passing in two empty lists for the products and the regions.
                |     Note: null values for products and regions are not
                |     accepted.
                | 
                |     Parameters:
                | 
                |         iProducts
                |             Safe array of products for the excluded region, as CATIAReferences.
                |             This array has a one-to-one mapping with the regions array.
                |             
                |         iRegions
                |             Safe array of regions to exclude, as CATIAReferences. This array
                |             has a one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_regions:
        :rtype: None
        """
        return self.abq_smooth_coupling.SetExclusionRegions(i_products, i_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_exclusion_regions'
        # # vba_code = """
        # # Public Function set_exclusion_regions(abq_smooth_coupling)
        # #     Dim iProducts (2)
        # #     abq_smooth_coupling.SetExclusionRegions iProducts
        # #     set_exclusion_regions = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_handler(self, i_product: Reference, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandler(Reference iProduct,
                | Reference iRef)
                | 
                |     Sets the handler for the coupling. Any previously set handler will be
                |     replaced with this new value.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product for the handler. 
                |         iRef
                |             The reference to the handler.

        :param Reference i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abq_smooth_coupling.SetHandler(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler'
        # # vba_code = """
        # # Public Function set_handler(abq_smooth_coupling)
        # #     Dim iProduct (2)
        # #     abq_smooth_coupling.SetHandler iProduct
        # #     set_handler = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_handler_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandlerFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Sets the handler for the coupling. Any previously set handler will be
                |     replaced with this new value.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product for handeler.
                |         iPublication
                |             The CATIA Publication for handeler.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_smooth_coupling.SetHandlerFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler_from_publication'
        # # vba_code = """
        # # Public Function set_handler_from_publication(abq_smooth_coupling)
        # #     Dim iProduct (2)
        # #     abq_smooth_coupling.SetHandlerFromPublication iProduct
        # #     set_handler_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_local_csys_from_publication(self, i_product: Product, i_pub_axis_system: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLocalCsysFromPublication(Product iProduct,
                | Publication iPubAxisSystem)
                | 
                |     Sets the published local coordinate system for the coupling. Fails if the
                |     publication is not an axis system.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         iPublication
                |             The CATIA Publication on the axis system.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_pub_axis_system:
        :rtype: None
        """
        return self.abq_smooth_coupling.SetLocalCsysFromPublication(i_product.com_object, i_pub_axis_system.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_local_csys_from_publication'
        # # vba_code = """
        # # Public Function set_local_csys_from_publication(abq_smooth_coupling)
        # #     Dim iProduct (2)
        # #     abq_smooth_coupling.SetLocalCsysFromPublication iProduct
        # #     set_local_csys_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_supports(self, i_products: tuple, i_regions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSupports(CATSafeArrayVariant iProducts,
                | CATSafeArrayVariant iRegions)
                | 
                |     Sets the support regions for the coupling. Any previously set support
                |     regions will be replaced with this new list. At least one item in the list is
                |     required.
                | 
                |     Parameters:
                | 
                |         iProducts
                |             Safe array of products for the support region as CATIAReferences.
                |             This array has a one-to-one mapping with the regions array.
                |             
                |         iRegions
                |             Safe array of supports as CATIAReferences. This array has a
                |             one-to-one mapping with the products array.

        :param tuple i_products:
        :param tuple i_regions:
        :rtype: None
        """
        return self.abq_smooth_coupling.SetSupports(i_products, i_regions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_supports'
        # # vba_code = """
        # # Public Function set_supports(abq_smooth_coupling)
        # #     Dim iProducts (2)
        # #     abq_smooth_coupling.SetSupports iProducts
        # #     set_supports = iProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQSmoothCoupling(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.in_interfaces.position import Position
from pycatia.system_interfaces.any_object import AnyObject


class DNB3DState(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNB3DState
                | 
                | Interface representing the 3D State object.
                | 
                | Role: Represents a 3D State object and provides APIs to update an existing 3D
                | state object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_3d_state = com_object

    @property
    def state_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StateName() As CATBSTR
                | 
                |     Returns or sets the Name of the 3D State.
                | 
                |     Example:
                |         This example fetches the Name of a 3D State.
                | 
                |          Dim stateName As String
                |          stateName = mySelected3DState.StateName
                |
                |         This example sets the Name of a 3D State.
                | 
                |          mySelected3DState.StateName = "NewStateName"

        :rtype: str
        """

        return self.dnb_3d_state.StateName

    @state_name.setter
    def state_name(self, value: str):
        """
        :param str value:
        """

        self.dnb_3d_state.StateName = value

    def add_3d_position(self, i_position: Position) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Add3DPosition(DNBIA3DStatePosition iPosition)
                | 
                |     Adds the specified 3D Position to the given 3D state as a child. This input
                |     state object should be defined inside the product hierarchy of the ‘this’
                |     state. Otherwise this method would return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The 3D position object to be added.
                | 
                |             Example:
                |                 This example adds a specified 3D position to a 3D State as a
                |                 child.
                | 
                |                  Dim myState1 As DNB3DState
                |                  Dim myPostion As DNB3DStatePosition
                |                  myPostion = 
                |                  myState1.Add3DState(myPostion)

        :param DNBIA3DStatePosition i_position:
        :rtype: None
        """
        return self.dnb_3d_state.Add3DPosition(i_position.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add3_d_position'
        # # vba_code = """
        # # Public Function add3_d_position(dnb3_d_state)
        # #     Dim iPosition (2)
        # #     dnb3_d_state.Add3DPosition iPosition
        # #     add3_d_position = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_3d_state(self, i_state: 'DNB3DState') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Add3DState(DNB3DState iState)
                | 
                |     Adds the specified 3D state to the given 3D state as a child. This input
                |     state object should be defined inside the product hierarchy of the ‘this’
                |     state. Otherwise this method would return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iState
                |             The 3D State object to be added.
                | 
                |             Example:
                |                 This example adds a specified 3D state to a 3D State as a
                |                 child.
                | 
                |                  Dim myState1 As DNB3DState
                |                  Dim myState2 As DNB3DState
                |                  myState2 = 
                |                  myState1.Add3DState(myState2)

        :param DNB3DState i_state:
        :rtype: None
        """
        return self.dnb_3d_state.Add3DState(i_state.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add3_d_state'
        # # vba_code = """
        # # Public Function add3_d_state(dnb3_d_state)
        # #     Dim iState (2)
        # #     dnb3_d_state.Add3DState iState
        # #     add3_d_state = iState
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def assign_3d_state(self, i_process: Activity, i_condition: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Assign3DState(Activity iProcess,
                | CATBSTR iCondition)
                | 
                |     Assigns the 3D state to a specified process, based on the given
                |     condition.
                | 
                |     Parameters:
                | 
                |         iProcess
                |             The activity to which the 3D state is to be assigned.
                |             
                |         iCondition
                |             The condition on which the 3D state is assigned to the specified
                |             process. iCondition should be one of "Begin Condition" or "End Condition" or
                |             "3D Context"
                | 
                |             Example:
                |                 This example assigns myState to mySelectedAct as a "Begin
                |                 Condition" .
                | 
                |                  Dim myState As DNB3DState
                |                  mySelectedAct = 
                |                  myState = 
                |                  myState1.Assign3DState(mySelectedAct, "Begin
                |                  Condition")

        :param Activity i_process:
        :param str i_condition:
        :rtype: None
        """
        return self.dnb_3d_state.Assign3DState(i_process.com_object, i_condition)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'assign3_d_state'
        # # vba_code = """
        # # Public Function assign3_d_state(dnb3_d_state)
        # #     Dim iProcess (2)
        # #     dnb3_d_state.Assign3DState iProcess
        # #     assign3_d_state = iProcess
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_children(self, i_type: str, o_children_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetChildren(CATBSTR iType,
                | CATSafeArrayVariant oChildrenArray)
                | 
                |     Returns the list of all the 3D states or 3D positions or both, managed by
                |     the given 3D state.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of children to be obtained which can be "3D State" or "3D
                |             Position" or "All". 
                | 
                |     Returns:
                |         oChildrenArray The list of 3D states or 3D positions or both, managed
                |         by the given 3D state.
                | 
                |         Example:
                |             This example returns the list of 3D States managed by
                |             myState.
                | 
                |              Dim myState As DNB3DState
                |              Dim statesArray() 
                |              myState = 
                |              numStates = myState.GetNumberOfChildren("3D State")
                |              Redim statesArray(numStates - 1)
                |              myState.GetChildren "3D State",statesArray

        :param str i_type:
        :param tuple o_children_array:
        :rtype: None
        """
        return self.dnb_3d_state.GetChildren(i_type, o_children_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_children'
        # # vba_code = """
        # # Public Function get_children(dnb3_d_state)
        # #     Dim iType (2)
        # #     dnb3_d_state.GetChildren iType
        # #     get_children = iType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_condition_name(self, i_related_activity: Activity) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConditionName(Activity iRelatedActivity) As
                | CATBSTR
                | 
                |     Returns the condition type on which the 3D State has been assigned to a
                |     specified activity.
                | 
                |     Parameters:
                | 
                |         iRelatedActivity
                |             The activity to which the 3D state has been assigned based on a
                |             condition. 
                | 
                |     Returns:
                |         oConditonName The condition type on which the 3D State has been
                |         assigned and can have the value as "Begin Condition" or "End Condition" or "3D
                |         Context"
                | 
                |         Example:
                |             This example returns the condition on which the given activity has
                |             been assigned to the state.
                | 
                |              Dim myState As DNB3DState
                |              Dim conditionName as String
                |              Dim activitiesArray()
                |              myState = 
                |              mySelectedAct = 
                |              conditionName = myState.GetConditionName(iRelatedActivity)

        :param Activity i_related_activity:
        :rtype: str
        """
        return self.dnb_3d_state.GetConditionName(i_related_activity.com_object)

    def get_number_of_children(self, i_type: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfChildren(CATBSTR iType) As long
                | 
                |     Returns the number of 3D states or 3D positions or both, managed by the
                |     given 3D state.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of children to be obtained which can be "3D State" or "3D
                |             Position" or "All". 
                | 
                |     Returns:
                |         oNumberOfChild The number of 3D states or 3D positions or both, managed
                |         by the given 3D state.
                | 
                |         Example:
                |             This example returns the number of 3D States managed by
                |             myState.
                | 
                |              Dim myState As DNB3DState
                |              Dim statesArray() 
                |              myState = 
                |              numStates = myState.GetNumberOfChildren("3D State")

        :param str i_type:
        :rtype: int
        """
        return self.dnb_3d_state.GetNumberOfChildren(i_type)

    def get_number_of_related_activities(self, i_condition_type: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberofRelatedActivities(CATBSTR iConditionType) As
                | long
                | 
                |     Returns the number of activities/processes associated with the 3D State
                |     based on the condition on which the state has been
                |     assigned.
                | 
                |     Parameters:
                | 
                |         iConditionType
                |             The condition on which the state has been assigned. The condition
                |             type should be one of "Begin Condition" or "End Condition" or "3D Context" or
                |             "All". 
                | 
                |     Returns:
                |         oNumActivities The number of activities assigned to the given 3D state
                |         based on the specified condition.
                | 
                |         Example:
                |             This example returns the number of activities assigned to myState
                |             as a "End Condition".
                | 
                |              Dim myState As DNB3DState
                |              Dim activitiesArray()
                |              myState = 
                |              numOfActivities = myState.GetNumberofRelatedActivities("End Conditon")

        :param str i_condition_type:
        :rtype: int
        """
        return self.dnb_3d_state.GetNumberofRelatedActivities(i_condition_type)

    def get_parent(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetParent() As CATBaseDispatch
                | 
                |     Returns the parent for the 3D State
                | 
                |     Returns:
                |         oParent The parent under which the 3D state has been created which
                |         could be "3D States" or "Mfg Positions"
                | 
                |         Example:
                |             This example returns the number of activities assigned to myState
                |             as a "End Condition".
                | 
                |              Dim myState As DNB3DState
                |              myState = 
                |              parentObj = myState.GetParent

        :rtype: AnyObject
        """
        return self.dnb_3d_state.GetParent()

    def get_related_activities(self, i_condition_type: str, o_activities_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRelatedActivities(CATBSTR iConditionType,
                | CATSafeArrayVariant oActivitiesArray)
                | 
                |     Returns the list of activities/processes associated with the 3D State based
                |     on the condition on which the state has been assigned.
                | 
                |     Parameters:
                | 
                |         iConditionType
                |             The condition on which the state has been assigned. The condition
                |             type should be one of "Begin Condition" or "End Condition" or "3D Context" or
                |             "All". 
                | 
                |     Returns:
                |         oActivitiesArray The list of activities assigned to the given 3D state
                |         based on the specified condition.
                | 
                |         Example:
                |             This example returns the list of activities assigned to myState as
                |             a "End Condition".
                | 
                |              Dim myState As DNB3DState
                |              Dim activitiesArray()
                |              myState = 
                |              numOfActivities = myState.GetNumberofRelatedActivities("End Conditon")
                |              Redim activitiesArray(numOfActivities - 1)
                |              myState.GetRelatedActivities "End
                |              Conditon",activitiesArray

        :param str i_condition_type:
        :param tuple o_activities_array:
        :rtype: None
        """
        return self.dnb_3d_state.GetRelatedActivities(i_condition_type, o_activities_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_related_activities'
        # # vba_code = """
        # # Public Function get_related_activities(dnb3_d_state)
        # #     Dim iConditionType (2)
        # #     dnb3_d_state.GetRelatedActivities iConditionType
        # #     get_related_activities = iConditionType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_related_object(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRelatedObject() As CATBaseDispatch
                | 
                |     Returns the product/resource/MA/ASTMA on which the given state is being
                |     defined.
                | 
                |     Returns:
                |         oRelatedObj The product/resource/MA/ASTMA on which the given state is
                |         being defined.
                | 
                |         Example:
                |             This example returns the product/resource/MA/ASTMA on which the
                |             given state is being defined.
                | 
                |              Dim myState As DNB3DState
                |              myState = 
                |              Set relObj = myState.GetRelatedObject

        :rtype: AnyObject
        """
        return self.dnb_3d_state.GetRelatedObject()

    def remove_3d_position(self, i_position: Position) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove3DPosition(DNBIA3DStatePosition iPosition)
                | 
                |     Removes the specified 3D position from the given 3D state’s definition
                |     list
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The 3D position object to be removed.
                | 
                |             Example:
                |                 This example removes a specified 3D state from a 3D state's
                |                 definition list .
                | 
                |                  Dim myState1 As DNB3DState
                |                  Dim myPostion As DNB3DStatePosition
                |                  myPostion = 
                |                  myState1.Remove3DPosition(myPostion)

        :param DNBIA3DStatePosition i_position:
        :rtype: None
        """
        return self.dnb_3d_state.Remove3DPosition(i_position.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove3_d_position'
        # # vba_code = """
        # # Public Function remove3_d_position(dnb3_d_state)
        # #     Dim iPosition (2)
        # #     dnb3_d_state.Remove3DPosition iPosition
        # #     remove3_d_position = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_3d_state(self, i_state: 'DNB3DState') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove3DState(DNB3DState iState)
                | 
                |     Removes the specified 3D state from the given 3D state’s definition
                |     list
                | 
                |     Parameters:
                | 
                |         iState
                |             The 3D State object to be removed.
                | 
                |             Example:
                |                 This example removes a specified 3D state from a 3D state's
                |                 definition list .
                | 
                |                  Dim myState1 As DNB3DState
                |                  Dim myState2 As DNB3DState
                |                  myState2 = 
                |                  myState1.Remove3DState(myState2)

        :param DNB3DState i_state:
        :rtype: None
        """
        return self.dnb_3d_state.Remove3DState(i_state.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove3_d_state'
        # # vba_code = """
        # # Public Function remove3_d_state(dnb3_d_state)
        # #     Dim iState (2)
        # #     dnb3_d_state.Remove3DState iState
        # #     remove3_d_state = iState
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def unassign_3d_state(self, i_process: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Unassign3DState(Activity iProcess)
                | 
                |     Unassigns the 3D state from a specified process.
                | 
                |     Parameters:
                | 
                |         iProcess
                |             The activity from which the 3D state is to be
                |             unassigned.
                | 
                |             Example:
                |                 This example unassigns myState from
                |                 mySelectedAct.
                | 
                |                  Dim myState As DNB3DState
                |                  mySelectedAct = 
                |                  myState = 
                |                  myState.Assign3DState(mySelectedAct)

        :param Activity i_process:
        :rtype: None
        """
        return self.dnb_3d_state.Unassign3DState(i_process.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'unassign3_d_state'
        # # vba_code = """
        # # Public Function unassign3_d_state(dnb3_d_state)
        # #     Dim iProcess (2)
        # #     dnb3_d_state.Unassign3DState iProcess
        # #     unassign3_d_state = iProcess
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DNB3DState(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_resource_program_interfaces.task import Task
from pycatia.system_interfaces.any_object import AnyObject


class ResourceProgramManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ResourceProgramManager
                | 
                | Represents the Resource Program manager of a resource.
                | 
                | Role: Resource Program manager is the object used to access the tasks
                | associated to the resource.
                | The following code snippet can be used to obtain the Resource Program manager
                | from the robot product.
                | 
                |    Dim objResourceProgramManager As ResourceProgramManager
                |    Dim objRobot as Product
                |    
                |    Set objResourceProgramManager = objRobot.GetTechnologicalObject("ResourceProgramManager" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.resource_program_manager = com_object

    def get_all_tasks(self, o_task_list: tuple) -> Task:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllTasks(CATSafeArrayVariant oTaskList)
                | 
                |     Retrieves all the Tasks corresponding to this Resource.
                | 
                |     Parameters:
                | 
                |         oTaskList
                |             The list of Tasks. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Tasks were corrrectly retrieved
                |         E_FAIL
                |             The Tasks were not corrrectly retrieved
                | 
                |         Example:
                |             The following example retrieves the list of tasks on the
                |             resource.
                | 
                |                Dim objResourceProgramManager As
                |                ResourceProgramManager
                |                Dim TaskList(3) As Task
                |                ..
                |                objResourceProgramManager.GetAllTasks TaskList

        :param tuple o_task_list:
        :rtype: Task
        """
        return Task(self.resource_program_manager.GetAllTasks(o_task_list))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_tasks'
        # # vba_code = """
        # # Public Function get_all_tasks(resource_program_manager)
        # #     Dim oTaskList (2)
        # #     resource_program_manager.GetAllTasks oTaskList
        # #     get_all_tasks = oTaskList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_task(self, i_task_name: str, o_task: Task) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTask(CATBSTR iTaskName,
                | Task oTask)
                | 
                |     Retrieves the Tasks corresponding to the given Task Name.
                | 
                |     Parameters:
                | 
                |         iTaskName
                |             The name of the Task. 
                |         oTask
                |             The output Task. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Task was corrrectly retrieved
                |         E_FAIL
                |             The Task was not corrrectly retrieved
                | 
                |         Example:
                |             The following example Retrieves the task corresponding the given
                |             task name.
                | 
                |                Dim objResourceProgramManager As
                |                ResourceProgramManager
                |                Dim oTask As Task
                |                ..
                |                objResourceProgramManager.GetTask  "RobotTask.1",
                |                oTask

        :param str i_task_name:
        :param Task o_task:
        :rtype: None
        """
        return self.resource_program_manager.GetTask(i_task_name, o_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_task'
        # # vba_code = """
        # # Public Function get_task(resource_program_manager)
        # #     Dim iTaskName (2)
        # #     resource_program_manager.GetTask iTaskName
        # #     get_task = iTaskName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ResourceProgramManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_mesh_local_specifications import AnalysisMeshLocalSpecifications
from pycatia.analysis_interfaces.analysis_set import AnalysisSet
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.types.general import cat_variant


class AnalysisMeshPart(AnalysisSet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAnalysisInterfaces.AnalysisSet
                |                         AnalysisMeshPart
                | 
                | The interface to access a CATIAAnalysisMeshPart.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_mesh_part = com_object

    @property
    def activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Activity() As boolean
                | 
                |     Returns the activity of an meshpart.
                | 
                |     Parameters:
                | 
                |         oActivity
                | 
                |             Legal values:
                | 
                |             FALSE
                |                 Mesh Part is not active. 
                |             TRUE
                |                 Mesh Part is active.

        :rtype: bool
        """

        return self.analysis_mesh_part.Activity

    @activity.setter
    def activity(self, value: bool):
        """
        :param bool value:
        """

        self.analysis_mesh_part.Activity = value

    @property
    def analysis_mesh_local_specifications(self) -> AnalysisMeshLocalSpecifications:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisMeshLocalSpecifications() As
                | AnalysisMeshLocalSpecifications (Read Only)
                | 
                |     Returns the local specification collection from the meshpart analysis.

        :rtype: AnalysisMeshLocalSpecifications
        """

        return AnalysisMeshLocalSpecifications(self.analysis_mesh_part.AnalysisMeshLocalSpecifications)

    def add_support_from_publication(self, i_product: Product, i_support: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iSupport)
                | 
                |     Creates a new support and add it to the support description of the mesh
                |     part.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iPublication
                |             the CATIA Publication that represent the the geometry to
                |             meshed.
                | 
                |     See also:
                |         Publication, Product

        :param Product i_product:
        :param Publication i_support:
        :rtype: None
        """
        return self.analysis_mesh_part.AddSupportFromPublication(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(analysis_mesh_part)
        # #     Dim iProduct (2)
        # #     analysis_mesh_part.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Product iProduct,
                | Reference iSupport)
                | 
                |     Creates a new support and add it to the support description of the mesh
                |     part.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iSupport
                |             the CATIA Reference that represent the geometry to
                |             meshed.
                | 
                |     See also:
                |         Reference, Product

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.analysis_mesh_part.AddSupportFromReference(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(analysis_mesh_part)
        # #     Dim iProduct (2)
        # #     analysis_mesh_part.AddSupportFromReference iProduct
        # #     add_support_from_reference = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_global_specification(self, i_name: str, i_value: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGlobalSpecification(CATBSTR iName,
                | CATVariant iValue)
                | 
                |     Sets the value corresponding to the given global
                |     specification.
                | 
                |     Parameters:
                | 
                |         iName
                |             The identifier if the global specification.
                |         iValue
                |             The value of the global specification.

        :param str i_name:
        :param cat_variant i_value:
        :rtype: None
        """
        return self.analysis_mesh_part.SetGlobalSpecification(i_name, i_value)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_global_specification'
        # # vba_code = """
        # # Public Function set_global_specification(analysis_mesh_part)
        # #     Dim iName (2)
        # #     analysis_mesh_part.SetGlobalSpecification iName
        # #     set_global_specification = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mesh_parts_to_capture(self, i_mesh_parts: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMeshPartsToCapture(CATSafeArrayVariant iMeshParts)
                | 
                |     Set the list of candidate Mesh Parts for capture.
                | 
                |     Parameters:
                | 
                |         iMeshParts
                |             Safe array of mesh parts. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             Operation successfull. 
                |         E_FAIL
                |             Operation failed.

        :param tuple i_mesh_parts:
        :rtype: None
        """
        return self.analysis_mesh_part.SetMeshPartsToCapture(i_mesh_parts)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mesh_parts_to_capture'
        # # vba_code = """
        # # Public Function set_mesh_parts_to_capture(analysis_mesh_part)
        # #     Dim iMeshParts (2)
        # #     analysis_mesh_part.SetMeshPartsToCapture iMeshParts
        # #     set_mesh_parts_to_capture = iMeshParts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_specification_from_publication(
            self,
            i_name: str,
            i_product: Product,
            i_support: Publication,
            i_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpecificationFromPublication(CATBSTR iName,
                | Product iProduct,
                | Publication iSupport,
                | long iMode)
                | 
                |     Adds the geometric value corresponding to the given global
                |     specification.
                | 
                |     Parameters:
                | 
                |         iName
                |             The identifier if the global specification.
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iPublication
                |             the CATIA Publication that represent the the geometry to
                |             meshed.
                | 
                |     See also:
                |         Publication, Product 
                |     iMode
                |         The mode used to valuate the publication global
                |         specification.
                |         Legal values:
                | 
                |         0
                |             the global specification is defined as a single reference.
                |             
                |         1
                |             the global specification is added to exising
                |             references.

        :param str i_name:
        :param Product i_product:
        :param Publication i_support:
        :param int i_mode:
        :rtype: None
        """
        return self.analysis_mesh_part.SetSpecificationFromPublication(
            i_name,
            i_product.com_object,
            i_support.com_object,
            i_mode
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_specification_from_publication'
        # # vba_code = """
        # # Public Function set_specification_from_publication(analysis_mesh_part)
        # #     Dim iName (2)
        # #     analysis_mesh_part.SetSpecificationFromPublication iName
        # #     set_specification_from_publication = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_specification_from_reference(
            self,
            i_name: str,
            i_product: Product,
            i_support: Reference,
            i_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpecificationFromReference(CATBSTR iName,
                | Product iProduct,
                | Reference iSupport,
                | long iMode)
                | 
                |     Set the geometric value corresponding to the given global
                |     specification.
                | 
                |     Parameters:
                | 
                |         iName
                |             The identifier if the global specification.
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iSupport
                |             the CATIA Reference that represent the geometry to
                |             meshed.
                | 
                |     See also:
                |         Reference, Product 
                |     iMode
                |         The mode used to valuate the reference global
                |         specification.
                |         Legal values:
                | 
                |         0
                |             the global specification is defined as a single reference.
                |             
                |         1
                |             the global specification is added to exising
                |             references.

        :param str i_name:
        :param Product i_product:
        :param Reference i_support:
        :param int i_mode:
        :rtype: None
        """
        return self.analysis_mesh_part.SetSpecificationFromReference(
            i_name,
            i_product.com_object,
            i_support.com_object,
            i_mode
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_specification_from_reference'
        # # vba_code = """
        # # Public Function set_specification_from_reference(analysis_mesh_part)
        # #     Dim iName (2)
        # #     analysis_mesh_part.SetSpecificationFromReference iName
        # #     set_specification_from_reference = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisMeshPart(name="{self.name}")'
